@@ -1,36 +1,10 @@
 # test.glmnet.R: glmnet tests for plotmo and plotres
 
-options(warn=1) # print warnings as they occur
-
-if(!interactive())
-    postscript(paper="letter")
-
-printf <- function(format, ...) cat(sprintf(format, ...), sep="") # like c printf
-
-strip.space <- function(s) gsub("[ \t\n]", "", s)
-
-# test that we got an error as expected from a try() call
-expect.err <- function(object, expected.msg="")
-{
-    if(class(object)[1] == "try-error") {
-        msg <- attr(object, "condition")$message[1]
-        if(length(grep(expected.msg, msg, fixed=TRUE)))
-            cat("Got error as expected from ",
-                deparse(substitute(object)), "\n", sep="")
-        else
-            stop(sprintf("Expected: %s\n  Got:      %s",
-                         expected.msg, substr(msg[1], 1, 1000)))
-    } else
-        stop("Did not get expected error: ", expected.msg)
-}
-printf("library(earth)\n")
+source("test.prolog.R")
 library(earth)
-printf("library(glmnet)\n")
 library(glmnet)
-
 data(ozone1)
 data(etitanic)
-
 get.tit <- function() # abbreviated titanic data
 {
     tit <- etitanic
@@ -533,7 +507,4 @@ plot_glmnet(mod, col=c("black","red","green",0,0,0,0,0,"steelblue","darkorange")
 plot_glmnet(mod, col=c("black","red", 0), main="col=c('black','red', 0)") # test recycling, including 0
 par(old.par)
 
-if(!interactive()) {
-    dev.off()         # finish postscript plot
-    q(runLast=FALSE)  # needed else R prints the time on exit (R2.5 and higher) which messes up the diffs
-}
+source("test.epilog.R")
